LC codec implementation for the numcodecs API.
Structs
- LcCodec
- Codec providing compression using LC
- LcCoding
Error - Opaque error for when encoding or decoding with LC fails
- LcHeader
Error - Opaque error for when encoding or decoding the header fails
Enums
- LcCodec
Error - Errors that may occur when applying the
LcCodec. - LcComponent
- LC component
- LcDecorrelation
- LC quantisation decorrelation mode
- LcElem
Size - LC component element size, in bytes
- LcError
Kind - LC error bound kind
- LcFloat
Size - LC component float element size, in bytes
- LcLorenzo
Dtype - LC Lorenzo preprocessor dtype
- LcPreprocessor
- LC preprocessor
- LcQuantizeD
Type - LC quantization dtype
- LcTuple
Size - LC tuple component element size, in bytes x tuple length
Functions
- compress
- Compress the
arrayusing LC with the providedpreprocessorsandcomponents. - decompress
- Decompress the
encodeddata into an array using LC. - decompress_
into - Decompress the
encodeddata into adecodedarray using LC.