pub fn decompress_into(
preprocessors: &[LcPreprocessor],
components: &[LcComponent],
encoded: &[u8],
decoded: AnyArrayViewMut<'_>,
) -> Result<(), LcCodecError>Expand description
Decompress the encoded data into a decoded array using LC.
Errors
Errors with
LcCodecError::HeaderDecodeFailedif decoding the header failedLcCodecError::MismatchedDecodeIntoArrayif thedecodedarray is of the wrong dtype or shapeLcCodecError::HeaderDecodeFailedif decoding the header failedLcCodecError::DecodeDataLengthMismatchif decoding produced a different number of bytes than expectedLcCodecError::LcDecodeFailedif an opaque decoding error occurred